{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf;

  cfg = config.pepe.services.nzbget;
in
{
  options.pepe.services.nzbget = with lib; {
    enable = mkEnableOption "Enable nzbget";
    package = mkPackageOption pkgs "nzbget" { };
    domain = mkOption {
      type = types.str;
      default = null;
    };
  };

  config = mkIf cfg.enable {
    services.nzbget = {
      enable = true;
      package = cfg.package;
      group = "media";
    };

    architect.vhost.${cfg.domain} = with config.architect.networks; {
      dnsInterfaces = [ "tailscale" "lan" ];
      locations."/" = {
        port = 6789;
        allowLan = true;
        allow = [
          tailscale.net
        ];
      };
    };

    pepe.core.media.groupMembers = mkIf config.pepe.core.media.enable [ "nzbget" ];
  };
}
